/*-
 * #%L
 * SciJava polyglot kernel for Jupyter.
 * %%
 * Copyright (C) 2017 Hadrien Mary
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

package org.scijava.notebook.converter.output;

/**
 * Base type for {@link NotebookOutput}s which produce HTML content.
 *
 * @author Hadrien Mary
 */
public abstract class HTMLFriendlyNotebookOutput extends NotebookOutput {

    public HTMLFriendlyNotebookOutput(String mimeTypeObj, String content) {
        super(mimeTypeObj, content);
    }

    public abstract String toHTML();

}
